@@ -1,7 +1,7 @@
 use std::{collections::BTreeMap, time::Duration};
 
 use chrono::Utc;
-use poem::{session::SessionStorage, Result};
+use poem::{error::InternalServerError, session::SessionStorage, Result};
 use sqlx::{sqlite::SqliteStatement, types::Json, Executor, SqlitePool, Statement};
 
 use crate::DatabaseConfig;
@@ -28,6 +28,10 @@ const CLEANUP_SQL: &str = r#"
 
 /// Session storage using Sqlite.
 ///
+/// # Errors
+///
+/// - [`sqlx::Error`]
+///
 /// # Create the table for session storage
 ///
 /// ```sql
@@ -99,14 +103,15 @@ impl SqliteSessionStorage {
 #[poem::async_trait]
 impl SessionStorage for SqliteSessionStorage {
     async fn load_session(&self, session_id: &str) -> Result<Option<BTreeMap<String, String>>> {
-        let mut conn = self.pool.acquire().await?;
+        let mut conn = self.pool.acquire().await.map_err(InternalServerError)?;
         let res: Option<(Json<BTreeMap<String, String>>,)> = self
             .load_stmt
             .query_as()
             .bind(session_id)
             .bind(Utc::now())
             .fetch_optional(&mut conn)
-            .await?;
+            .await
+            .map_err(InternalServerError)?;
         Ok(res.map(|(value,)| value.0))
     }
 
@@ -116,10 +121,12 @@ impl SessionStorage for SqliteSessionStorage {
         entries: &BTreeMap<String, String>,
         expires: Option<Duration>,
     ) -> Result<()> {
-        let mut conn = self.pool.acquire().await?;
+        let mut conn = self.pool.acquire().await.map_err(InternalServerError)?;
 
         let expires = match expires {
-            Some(expires) => Some(chrono::Duration::from_std(expires)?),
+            Some(expires) => {
+                Some(chrono::Duration::from_std(expires).map_err(InternalServerError)?)
+            }
             None => None,
         };
 
@@ -129,17 +136,19 @@ impl SessionStorage for SqliteSessionStorage {
             .bind(Json(entries))
             .bind(expires.map(|expires| Utc::now() + expires))
             .execute(&mut conn)
-            .await?;
+            .await
+            .map_err(InternalServerError)?;
         Ok(())
     }
 
     async fn remove_session(&self, session_id: &str) -> Result<()> {
-        let mut conn = self.pool.acquire().await?;
+        let mut conn = self.pool.acquire().await.map_err(InternalServerError)?;
         self.remove_stmt
             .query()
             .bind(session_id)
             .execute(&mut conn)
-            .await?;
+            .await
+            .map_err(InternalServerError)?;
         Ok(())
     }
 }
